package main;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Set;

import javax.inject.Inject;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.xtext.junit4.InjectWith;
import org.eclipse.xtext.junit4.XtextRunner;
import org.eclipse.xtext.ui.resource.IResourceSetProvider;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.xtext.example.mydsl.MyDslUiInjectorProvider;

import utils.ModelBuilder;
import utils.WorkspaceUtils;
import utils.XMIUtils;

@RunWith(XtextRunner.class)
@InjectWith(MyDslUiInjectorProvider.class)
public class SampleTest {

	@Inject
	IResourceSetProvider resourceSetProvider;

	@Test
	public void testIt() {
		IWorkspaceRoot workspaceRoot = ResourcesPlugin.getWorkspace().getRoot();
		IProject project = workspaceRoot.getProject("ArchitectureTest");
		assertTrue(project.exists());
		System.out.println(project.getLocation().toOSString());
		ResourceSet resourceSet = this.resourceSetProvider.get(project);
		System.out.println("ArchitectureTest project found.");
		Set<IFile> dslFiles = WorkspaceUtils.getAllDSLFilesInFolder(
				project.getLocation(), ".mydsl");
		System.out.println("Found " + dslFiles.size() + " DSL files.");
		assertEquals(20, dslFiles.size());
		Set<EObject> modelElements = WorkspaceUtils.getModelElements(dslFiles,
				resourceSet);
		System.out.println("Read " + modelElements.size()
				+ " model root elements.");
		EObject modelRoot = ModelBuilder.build(modelElements);
		System.out.println("Built root model.");
		String XMI = XMIUtils.serializeEObjectToXMI(modelRoot, resourceSet);
		System.out.println("The serialized model XMI contents");
		System.out.println();
		System.out.println();
		System.out.println(XMI);
		// this should hold, but it doesn't
		assertTrue(XMI.contains("xtextLink") == false);
	}

}